@@ -71,8 +71,12 @@ impl Api {
             .map_or(false, |status| status == reqwest::StatusCode::UNAUTHORIZED)
     }
 
-    pub(crate) async fn create_state(&self, state: v0::CreateStateDto) -> ApiResult<v0::State> {
-        self.post("/states", state).await
+    pub(crate) async fn create_state(
+        &self,
+        state: v0::CreateStateDto,
+        params: Vec<(String, String)>,
+    ) -> ApiResult<v0::State> {
+        self.post("/states", state, &params).await
     }
 
     pub(crate) async fn create_volume(
@@ -81,7 +85,7 @@ impl Api {
         volume: v0::CreateVolumeDto,
     ) -> ApiResult<v0::Volume> {
         let path = format!("/states/{state_name}/volumes", state_name = state_name);
-        self.post(path, volume).await
+        self.post(path, volume, &[]).await
     }
 
     pub(crate) async fn delete_volume(
@@ -169,7 +173,7 @@ impl Api {
             provider,
             locations,
         };
-        self.post("/clusters", body).await
+        self.post("/clusters", body, &[]).await
     }
 
     pub(crate) async fn unregister_cluster(&self, name: &v0::ClusterName) -> ApiResult<()> {
@@ -197,7 +201,7 @@ impl Api {
     ) -> ApiResult<v0::StateLocationAws> {
         let path = format!("/states/{name}/locations/aws", name = name);
         let body = v0::CreateStateLocationAwsDto { region };
-        self.post(path, body).await
+        self.post(path, body, &[]).await
     }
 
     pub(crate) async fn del_aws_location(
@@ -233,7 +237,7 @@ impl Api {
     ) -> ApiResult<v0::StateLocationAzure> {
         let path = format!("/states/{name}/locations/azure", name = name);
         let body = v0::CreateStateLocationAzureDto { region };
-        self.post(path, body).await
+        self.post(path, body, &[]).await
     }
 
     pub(crate) async fn del_azure_location(
@@ -272,14 +276,14 @@ impl Api {
         cluster: &v0::ClusterName,
     ) -> ApiResult<v0::ClusterToken> {
         let path = format!("/clusters/{}/token", cluster);
-        self.post::<_, _, (), _>(path, None).await
+        self.post::<_, _, (), _>(path, None, &[]).await
     }
 
     pub(crate) async fn report_event<T>(&self, event: &v0::Report<T>) -> ApiResult<()>
     where
         T: ser::Serialize,
     {
-        self.post("/events", event).await
+        self.post("/events", event, &[]).await
     }
 
     pub(crate) fn url(&self, path: impl fmt::Display) -> String {
@@ -340,7 +344,7 @@ impl Api {
             .inspect(|output| self.inspect(output))
     }
 
-    async fn post<P, B, T, U>(&self, path: P, body: B) -> ApiResult<U>
+    async fn post<P, B, T, U>(&self, path: P, body: B, query: &[(String, String)]) -> ApiResult<U>
     where
         P: fmt::Display,
         B: Into<Option<T>>,
@@ -351,6 +355,7 @@ impl Api {
         let url = self.url(path);
         self.client()?
             .post(url)
+            .query(query)
             .optionally_bearer_auth(self.token.as_ref())
             .inspect()
             .optionally_json(body.as_ref())
