@@ -18,7 +18,8 @@
 #![warn(unused)]
 #![deny(warnings)]
 
-use location::Location;
+use statehub_api::{location, v0};
+
 use output::Output;
 use statehub::Cli;
 
@@ -26,8 +27,6 @@ use statehub::Cli;
 mod api;
 // K8s interface and helpers
 mod k8s;
-// Location definitions
-mod location;
 // `Output` wrapper
 mod output;
 // `Show` trait definition and impls
@@ -36,8 +35,6 @@ mod show;
 mod statehub;
 // custom traits
 mod traits;
-// stathub API v0 definitions
-pub mod v0;
 
 #[tokio::main]
 async fn main() -> anyhow::Result<()> {
